@@ -1,6 +1,7 @@
 import numpy as np
 
-from autoarray.structures import arrays, grids
+from autoarray.structures import arrays
+from autoarray.structures import grids
 from autoarray.util import array_util, grid_util
 
 
