@@ -1,6 +1,7 @@
 import logging
 
 import numpy as np
+import pylops
 
 from autoarray.util import array_util
 
@@ -17,15 +18,21 @@ class AbstractVisibilities(np.ndarray):
         Parameters
         ----------
         array_1d: ndarray
-            An array representing image (e.g. an image, noise map, etc.)
+            An array representing image (e.g. an image, noise-map, etc.)
         pixel_scales: (float, float)
             The arc-second to pixel conversion factor of each pixel.
         origin : (float, float)
             The arc-second origin of the hyper array's coordinate system.
         """
         obj = visibilities_1d.view(cls)
+        obj._as_complex = None
         return obj
 
+    def __array_finalize__(self, obj):
+
+        if hasattr(obj, "_as_complex"):
+            self._as_complex = obj._as_complex
+
     def __reduce__(self):
         # Get the parent's __reduce__ tuple
         pickled_state = super(AbstractVisibilities, self).__reduce__()
@@ -89,6 +96,14 @@ class AbstractVisibilities(np.ndarray):
     def phases(self):
         return np.arctan2(self.imag, self.real)
 
+    @property
+    def as_complex(self):
+        if self._as_complex is None:
+            self._as_complex = np.apply_along_axis(
+                lambda args: [complex(*args)], 1, self
+            )
+        return self._as_complex
+
     def output_to_fits(self, file_path, overwrite=False):
         array_util.numpy_array_2d_to_fits(
             array_2d=self, file_path=file_path, overwrite=overwrite
@@ -121,7 +136,7 @@ class Visibilities(AbstractVisibilities):
         if type(visibilities) is list:
             visibilities = np.asarray(visibilities)
 
-        return Visibilities(visibilities_1d=visibilities)
+        return cls(visibilities_1d=visibilities)
 
     @classmethod
     def full(cls, fill_value, shape_1d):
@@ -143,3 +158,51 @@ class Visibilities(AbstractVisibilities):
             file_path=file_path, hdu=hdu
         )
         return cls.manual_1d(visibilities=visibilities_1d)
+
+
+class VisibilitiesNoiseMap(Visibilities):
+
+    # noinspection PyUnusedLocal
+    def __new__(cls, visibilities_1d, *args, **kwargs):
+        """ A hyper array with square-pixels.
+
+        Parameters
+        ----------
+        array_1d: ndarray
+            An array representing image (e.g. an image, noise-map, etc.)
+        pixel_scales: (float, float)
+            The arc-second to pixel conversion factor of each pixel.
+        origin : (float, float)
+            The arc-second origin of the hyper array's coordinate system.
+        """
+        obj = super(VisibilitiesNoiseMap, cls).__new__(
+            cls=cls, visibilities_1d=visibilities_1d
+        )
+        obj.Wop = pylops.Diagonal(1.0 / obj.as_complex.ravel())
+        return obj
+
+    def __array_finalize__(self, obj):
+
+        if hasattr(obj, "_as_complex"):
+            self._as_complex = obj._as_complex
+
+        if hasattr(obj, "Wop"):
+            self.Wop = obj.Wop
+
+    def __reduce__(self):
+        # Get the parent's __reduce__ tuple
+        pickled_state = super(AbstractVisibilities, self).__reduce__()
+        # Create our own tuple to pass to __setstate__
+        class_dict = {}
+        for key, value in self.__dict__.items():
+            class_dict[key] = value
+        new_state = pickled_state[2] + (class_dict,)
+        # Return a tuple that replaces the parent's __setstate__ tuple with our own
+        return pickled_state[0], pickled_state[1], new_state
+
+    # noinspection PyMethodOverriding
+    def __setstate__(self, state):
+
+        for key, value in state[-1].items():
+            setattr(self, key, value)
+        super(AbstractVisibilities, self).__setstate__(state[0:-1])
